| WN_test | R Documentation |
WN_test() implements the white noise tests proposed in Chang, Yao and Zhou
(2017) and Chang et al. (2026+) for the following hypothesis testing problem:
H_0:\{{\bf y}_t
\}_{t=1}^n\mathrm{\ is\ white\ noise\ \ versus\ \ }H_1:\{{\bf y}_t
\}_{t=1}^n\mathrm{\ is\ not\ white\ noise.}
WN_test(
Y,
lag.k = 2,
B = 1000,
method = c("L_inf", "L_2"),
kernel.type = c("QS", "Par", "Bart"),
pre = FALSE,
alpha = 0.05,
control.PCA = list()
)
Y |
An |
lag.k |
The time lag |
B |
The number of bootstrap replications for calculating the critical value. The default is 1000. |
method |
The option for method used in the white noise test. Available options
include: |
kernel.type |
The option for choosing the symmetric kernel used
in the estimation of long-run covariance matrix, which is used when
|
pre |
Logical. This parameter is used when |
alpha |
The significance level of the test. The default is 0.05. |
control.PCA |
A list of control arguments passed to the function
|
An object of class "hdtstest", which contains the following
components:
statistic |
The test statistic of the test. |
p.value |
The p-value of the test. |
lag.k |
The time lag used in function. |
kernel.type |
The kernel used in function. |
Chang, J., He, J., Li, W., & Lin, C. (2026+). An adaptive L_2-type test
for high-dimensional white noise. Preprint.
Chang, J., Guo, B., & Yao, Q. (2018). Principal component analysis for second-order stationary vector time series. The Annals of Statistics, 46, 2094–2124. \Sexpr[results=rd]{tools:::Rd_expr_doi("doi:10.1214/17-AOS1613")}.
Chang, J., Yao, Q., & Zhou, W. (2017). Testing for high-dimensional white noise using maximum cross-correlations. Biometrika, 104, 111–127. \Sexpr[results=rd]{tools:::Rd_expr_doi("doi:10.1093/biomet/asw066")}.
PCA_TS
#Example 1
## Generate data
n <- 200
p <- 10
Y <- matrix(rnorm(n * p), n, p)
## L_inf
res1 <- WN_test(Y, method ="L_inf")
Pvalue1 <- res1$p.value
statistic1 <- res1$statistic
## L_2
res2 <- WN_test(Y, method = "L_2")
Pvalue2 <- res2$p.value
statistic2 <- res2$statistic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.